/*
 * Copyright 2013 Canonical Ltd.
 *
 * This file is part of ubuntu-calculator-app.
 *
 * ubuntu-calculator-app is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * ubuntu-calculator-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.Themes.Ambiance 0.1

Item {
    id: root
    width: parent.width
    height: row.height

    property int operationsWidth: operatorLabel.width+formulaLabel.width
    property string operation: ""
    property string numbers: ""
    property bool labelReadOnly: false
    property string labelText: ""
    property int numbersHeight: units.gu(4)
    property string numbersColor: '#FEFEFE'
    property bool isLast: false

    MouseArea {
        anchors.fill: parent
        propagateComposedEvents: true
        onClicked: {
            addFromMemory(root.numbers)
        }
    }

    Row{
        id: row
        height: numbersHeight
        width: parent.width
        Item {
            id: editIcon
            height: parent.height
            width: units.gu(3)

            Image {
                anchors.verticalCenter: parent.verticalCenter
                source: Qt.resolvedUrl("images/edit.png")
            }

            MouseArea {
                anchors.fill: parent
                onClicked: numberName.focus = true
            }
        }

        Item {
            width: row.width-editIcon.width-operatorLabel.width-formulaLabel.width
            height: parent.height

            TextField {
                id: numberName
                width: parent.width
                anchors.verticalCenter: parent.verticalCenter
                // removes ubuntu shape
                style: TextFieldStyle {
                    background: Item {}
                }

                readOnly: labelReadOnly
                text: labelText
                color: "#FEFEFE"
                onTextChanged: { labelText = numberName.text }
                hasClearButton: false
            }

            Image {
                visible: numberName.focus
                anchors.bottom: parent.bottom
                source: Qt.resolvedUrl("images/dot.png")
                fillMode: Image.Tile
                width: parent.width-units.gu(1)
                height: units.gu(1)/2
            }
        }

        Label {
            id: operatorLabel
            width: units.gu(4)
            anchors.verticalCenter: parent.verticalCenter
            font.pixelSize: units.gu(4)
            color: "#FEFEFE"
            text: root.operation
            font.family: "Ubuntu"
        }
        Label {
            id: formulaLabel

            // this property is used by autopilot tests to find the correct item
            // FIXME: implement it in a better way
            property bool isLast: root.isLast

            objectName: "formulaLabel"
            width: units.gu(25)
            color: numbersColor
            anchors.bottom: parent.bottom
            font.pixelSize: numbersHeight
            fontSizeMode: Text.Fit
            horizontalAlignment: Text.AlignRight
            text: root.numbers
            font.family: "Ubuntu"
        }
    }
}
