/*
 * Copyright 2013 Canonical Ltd.
 *
 * This file is part of ubuntu-calculator-app.
 *
 * ubuntu-calculator-app is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * ubuntu-calculator-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.Themes.Ambiance 0.1
import Ubuntu.Components.ListItems 0.1

//TODO: reuse a number clicking on it

Item{
    id: root
    height: _content.height + divider.height
    transformOrigin: Item.Bottom

    property var ops
    signal useAnswer(string answerToUse, string formulaData)
    signal labelTextUpdated(int idx, string newText)
    signal mainLabelUpdated(int idx, string newText)
    signal dateUpdate(int idx)
    signal removeItem()

    Item {
        visible: _content.x > parent.width / 5
        width: parent.width / 5
        height: parent.height

        Column {
            width: parent.width
            anchors.centerIn: parent
            Item {
                width: parent.width
                height: units.gu(4)
                Icon {
                    anchors.centerIn: parent
                    name: "user-trash-symbolic"
                    width: units.gu(2)
                    height: units.gu(2)
                }
            }

            Text {
                width: parent.width
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                color: "#9094AA"
                text: _content.x > root.width / 3 ? "Release To Delete" : "Pull To Delete"
                font.italic: true
                font.family: "Ubuntu"
            }
        }
    }

    Item {
        visible: _content.x < (-parent.width / 5)
        width: parent.width / 5
        height: parent.height
        anchors.right: parent.right

        Column {
            width: parent.width
            anchors.centerIn: parent
            Item {
                width: parent.width
                height: units.gu(4)
                Icon {
                    anchors.centerIn: parent
                    name: "user-trash-symbolic"
                    width: units.gu(2)
                    height: units.gu(2)
                }
            }

            Text {
                width: parent.width
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                color: "#9094AA"
                text: _content.x < -root.width / 3 ? "Release To Delete" : "Pull To Delete"
                font.italic: true
                font.family: "Ubuntu"
            }
        }
    }

    Item {
        id: _content
        width: parent.width
        height: inputs.height+units.gu(2)

        Column {
            id: inputs
            anchors.top: parent.top
            anchors.topMargin: units.gu(2)
            width: parent.width - units.gu(4)
            anchors.centerIn: parent

            // Every five minutes update date label
            Timer {
                interval: 300000
                repeat: true
                running: true
                onTriggered: root.dateUpdate(index)
            }

            Text {
                id: dateLabel
                width: parent.width
                color: "#9094AA"
                text: dateText
                font.italic: true
                font.family: "Ubuntu"
            }

            TextField{
                width: parent.width
                // removes ubuntu shape
                style: TextFieldStyle {
                    background: Item {}
                }
                text: mainLabel
                hasClearButton: false
                color: "#FEFEFE"
                onTextChanged: { root.mainLabelUpdated(index, text) }
            }

            Text {
                color: "#FEFEFE"
            }

            Repeater{
                id: repeater
                model: ops
                Column{
                    width: parent.width
                    spacing: units.gu(0.5)
                    Rectangle{
                        visible: (_operation == '=')
                        height: units.gu(0.1)
                        width: formulaLabel.operationsWidth
                        anchors.right: parent.right
                        color: "#FEFEFE"
                    }
                    Item {
                        visible: (_operation == '=')
                        height: units.gu(0.9)
                        width: formulaLabel.operationsWidth
                    }
                    CalcLabel {
                        id: formulaLabel
                        labelText: _text
                        numbers: _number
                        operation: _operation
                        numbersHeight: units.gu(5)
                        isLast: (isLastItem && index === repeater.model.count-1)

                        onLabelTextChanged: {
                            root.labelTextUpdated(index, labelText)
                        }
                    }
                }
            }

            /* Empty space */
            Item {
                height: units.gu(3)
                width: parent.width
            }
        }

        Behavior on x {
            NumberAnimation {
                duration: 200
            }
        }


        MouseArea {
            anchors.fill: isLastItem ? null : parent
            drag.target: _content
            drag.axis: Drag.XAxis
            drag.minimumX: isLastItem ? 0 : -_content.width
            drag.maximumX: isLastItem ? 0 : _content.width
            propagateComposedEvents: true

            function handleDrag() {
                if (Math.abs(_content.x) < parent.width/3) {
                    _content.x = 0
                }
                else {
                    if (_content.x < 0)
                        _content.x = -_content.width;
                    else
                        _content.x = _content.width;
                    root.removeItem()
                }
            }

            onReleased: handleDrag()
            onCanceled: handleDrag()
        }
    }

    Divider {
        id: divider
        visible: !isLastItem
        width: parent.width
        anchors {
            left: parent.left
            right: parent.right
            bottom: parent.bottom
        }
    }
}
